************
Mock Project
************

.. image:: https://img.shields.io/pypi/v/mock_project.svg
   :target: https://pypi.python.org/pypi/mock_project

.. image:: https://img.shields.io/pypi/pyversions/mock_project.svg
   :target: https://pypi.python.org/pypi/mock_project

.. image:: https://img.shields.io/travis/kalekundert/mock_project.svg
   :target: https://travis-ci.org/kalekundert/mock_project

.. image:: https://img.shields.io/coveralls/kalekundert/mock_project.svg
   :target: https://coveralls.io/github/kalekundert/mock_project?branch=master

Installation
============
To install use pip:

    $ pip install mock_project

Or clone the repo:

    $ git clone https://github.com/kalekundert/mock_project.git
    $ python setup.py install

Usage
=====
Coming soon...
